Face Scrambler
===============================

## Overview

Python package that creates scrambled versions of images of human faces.

## Installation

### 1. Install Anaconda

You need to install the scientific Python Distribution Anaconda.
Go to the [official download page](https://www.continuum.io/downloads) and klick on the link to download the Graphical 64-bit Installer for your system. It is important that you choose the **Python 2.7** version, not 3.6, as this package is not compatible with Python 3.x. Start the downloaded Installer and follow the steps. The installation might take a while.

### 2. Get OpenCV

The package depends on the popular Computer Vision library OpenCV.
Open a Terminal (Command Prompt in MS Windows) and type the following:

    $ conda install -c menpo opencv
    
When asked, type `y` and Enter to confirm the installation. 


### 3. Install face_scrambler

In the terminal, enter the following command:

    $ pip install face_scrambler
    
    
## Usage

Open the Interface by entering the `scrambler` into a terminal and confirming with enter.

[more information tbd]

    
## Implementation Details

TBD

